@@ -33,13 +33,14 @@ app = Typer()
 
 
 @app.callback(context_settings={"allow_extra_args": True, "ignore_unknown_options": True})
-def cli(ctx: Context,
-        verbose: str = Option(None, "-v", "--verbose", help="Verbose logging: info or debug"),
-        profile: str = Option(None, "-p", "--profile", help="Profile name if you want to override the default profile"),
-        output: str = Option("text", "-o", "--output", help="Output text or json"),
-        tenant: str = Option(None, "-t", "--tenant", help="Override the tenant for this command"),
-        domain: str = Option(None, "-d", "--domain", help="Override the domain for this command"),
-        ):
+def cli(
+    ctx: Context,
+    verbose: str = Option(None, "-v", "--verbose", help="Verbose logging: info or debug"),
+    profile: str = Option(None, "-p", "--profile", help="Profile name if you want to override the default profile"),
+    output: str = Option("text", "-o", "--output", help="Output text or json"),
+    tenant: str = Option(None, "-t", "--tenant", help="Override the tenant for this command"),
+    domain: str = Option(None, "-d", "--domain", help="Override the domain for this command"),
+):
     # by default we log out to console WARN and higher but can view info with -v
     # make sure this is called before importing the sdk so that we can grab all logging
     if verbose:
@@ -54,17 +55,20 @@ def cli(ctx: Context,
         except InvalidProfile as ex:
             log.debug(ex)
     try:
-        out(f"Tenant: {ctx.obj.session.profile.tenant} - Profile: {ctx.obj.session.profile_name} - Endpoint: {ctx.obj.session.profile.domain}")
+        out(
+            f"Tenant: {ctx.obj.session.profile.tenant} - Profile: {ctx.obj.session.profile_name} - Endpoint: {ctx.obj.session.profile.domain}"
+        )
     except:
         pass
     if ctx.invoked_subcommand not in ["tenants", "profile"]:
         if not ctx.obj.session:
             abort(f"You must create a profile with 'kamo profile add' to use this tool")
-        
+
         if ctx.invoked_subcommand not in ["version"]:
             if not ctx.obj.session.profile.tenant:
                 abort(f"You must select a tenant with 'kamo tenants' to use this tool")
 
+
 @app.command()
 def version(ctx: Context):
     """
@@ -75,9 +79,7 @@ def version(ctx: Context):
     ret = {"cli_version": kamocli.get_version_string()}
     ret["sdk_version"] = kamosdk.__version__
     ret["kamo_build_info"] = requests.get(ctx.obj.session.get_url("kamo")).json().get("build_info")
-    ret["knode_build_info"] = (
-        requests.get(ctx.obj.session.get_url("knode")).json().get("build_info")
-    )
+    ret["knode_build_info"] = requests.get(ctx.obj.session.get_url("knode")).json().get("build_info")
 
     if ctx.obj.output == "json" or 1:
         echo(dumps(ret))
